@@ -1,4 +1,4 @@
-;;; Copyright (C) 2010, 2011  Ludovic Courtès <ludo@gnu.org>
+;;; Copyright (C) 2010, 2011, 2012  Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; Libchop is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
   #:use-module (srfi srfi-26)
   #:use-module (ice-9 popen)
   #:use-module (ice-9 match)
+  #:use-module (ice-9 format)
   #:re-export (%libchop-libdir)
   #:export (c-offset-of
             c-size-of
@@ -61,6 +62,7 @@
             define-error-code
             raise-chop-error
             error/not-impl
+            gc-malloc
             gc-malloc-pointerless
 
             class-instance-size
@@ -85,6 +87,20 @@
     (lambda (size)
       (alloc size what))))
 
+(define gc-malloc
+  (let ((alloc
+         (pointer->procedure '* (dynamic-func "scm_gc_malloc" (dynamic-link))
+                             (list size_t '*)))
+        (what (string->pointer "chop")))
+    (lambda (size)
+      (alloc size what))))
+
+(define gc-realloc
+  ;; Don't use `scm_gc_realloc' because it wants the previous size, and
+  ;; because `GC_realloc' below really knows that size.
+  (pointer->procedure '* (dynamic-func "GC_realloc" (dynamic-link))
+                      (list '* size_t)))
+
 (define-syntax compile-time-value
   (syntax-rules ()
     "Evaluate the given expression at compile time.  The expression must
@@ -475,9 +491,7 @@ FIELD is assumed to have foreign type TYPE."
        (with-syntax (((params ...)
                       (generate-temporaries #'(args ...))))
          #'(lambda (params ...)
-             (let ((ptr (gc-malloc-pointerless
-                         (class-name-instance-size
-                          class-name))))
+             (let ((ptr (gc-malloc (class-name-instance-size class-name))))
                (init params ... ptr)
                (set-pointer-finalizer! ptr %destroy-object)
                (register-libchop-object! (wrap ptr)))))))))
@@ -498,9 +512,36 @@ C function NAME and wraps the resulting pointer with WRAP."
 ;;; Initialization.
 ;;;
 
-(define init (libchop-function "init" ()))
+;; Provide our own allocation routines so that the GC knows how much heap is
+;; really being used.  This is especially important since object like zip
+;; filters are associated with a fair amount of heap.  The test for this is:
+;;
+;;   (let loop ((i 300000)) (make-zlib-zip-filter) (loop (1- i)))
+
+(define init
+  (libchop-function "init_with_allocator" ('* '* '*)))
+
+(define (%malloc size class)
+  (gc-malloc size))
+
+(define (%realloc ptr size class)
+  (let ((size (if (= 0 size) 1 size)))
+    (gc-realloc ptr size)))
+
+(define (%free ptr class)
+  ;; Let the GC do its job.
+  #t)
+
+;; Keep the C closures in global variables to prevent them from being freed.
+(define %malloc-c-func
+  (procedure->pointer '* %malloc (list size_t '*)))
+(define %realloc-c-func
+  (procedure->pointer '* %realloc (list '* size_t '*)))
+(define %free-c-func
+  (procedure->pointer void %free '(* *)))
+
+(init %malloc-c-func %realloc-c-func %free-c-func)
 
-(init)
 
 ;; Bootstrap the object system.
 
@@ -545,9 +586,9 @@ C function NAME and wraps the resulting pointer with WRAP."
 ;;;
 
 (define register-weak-reference
-  (let ((refs (make-weak-value-hash-table)))
+  (let ((refs (make-weak-key-hash-table)))
     (lambda (source target)
-      (hash-set! refs source target))))
+      (hashq-set! refs source target))))
 
 (define (pointer+ p x)
   (make-pointer (+ (pointer-address p) x)))
@@ -564,8 +605,7 @@ C function NAME and wraps the resulting pointer with WRAP."
         (destroy   (dynamic-func "chop_buffer_return" libchop)))
     (lambda* (#:optional (size 0))
       "Return a pointer to a new `chop_buffer_t' object."
-      (let ((buf (bytevector->pointer
-                  (make-bytevector %size-of-chop_buffer_t))))
+      (let ((buf (gc-malloc %size-of-chop_buffer_t)))
         (init buf size)
         (set-pointer-finalizer! buf destroy)
         buf))))
