@@ -1,5 +1,5 @@
 ;;; libchop -- a utility library for distributed storage and data backup
-;;; Copyright (C) 2008, 2010, 2011  Ludovic Courtès <ludo@gnu.org>
+;;; Copyright (C) 2008, 2010, 2011, 2012  Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright (C) 2005, 2006, 2007  Centre National de la Recherche Scientifique (LAAS-CNRS)
 ;;;
 ;;; Libchop is free software: you can redistribute it and/or modify
@@ -26,22 +26,13 @@
   #:use-module (chop block-indexers)
   #:use-module (chop indexers)
   #:use-module (chop filters)
+  #:use-module (chop tests)
   #:use-module (rnrs bytevectors)
   #:use-module (rnrs io ports)
   #:use-module (srfi srfi-1)
   #:use-module (srfi srfi-11)
   #:use-module (srfi srfi-64))
 
-(define (with-temporary-file proc)
-  (let ((file (tmpnam)))
-    (dynamic-wind
-      (lambda ()
-        #t)
-      (lambda ()
-        (proc file))
-      (lambda ()
-        (delete-file file)))))
-
 
 ;;;
 ;;; Objects.
@@ -85,15 +76,6 @@
 
 (test-begin "streams")
 
-(define (make-random-bytevector n)
-  (let ((bv (make-bytevector n)))
-    (let loop ((i 0))
-      (if (< i n)
-          (begin
-            (bytevector-u8-set! bv i (random 256))
-            (loop (1+ i)))
-          bv))))
-
 (test-assert "/dev/null"
   (stream? (file-stream-open "/dev/null")))
 
@@ -188,6 +170,11 @@
     (store-write-block s #vu8(1 2 3) #vu8(7 7))
     #t))
 
+(test-assert "false-if-block-unavailable"
+  (with-temporary-store
+   (lambda (s)
+     (not (false-if-block-unavailable (store-read-block s #vu8(1 2 3)))))))
+
 (test-assert "gdbm"
   (with-temporary-file
    (lambda (file)
@@ -202,6 +189,39 @@
          (store-close s)
          r)))))
 
+(test-assert "store-delete-block"
+  (with-temporary-store
+   (lambda (s)
+     (let ((k #vu8(1 2 3 4))
+           (v (make-random-bytevector 123)))
+       (store-write-block s k v)
+       (and (bytevector=? v (store-read-block s k))
+            (eq? k (store-delete-block s k))
+            (catch 'chop-error
+              (lambda ()
+                (store-read-block s k)
+                #f)
+              (lambda (key err . rest)
+                (= err error/store-block-unavailable))))))))
+
+(test-assert "smart-block-store-open"
+  (with-temporary-file
+   (lambda (file)
+     (let* ((s  (file-based-block-store-open (lookup-class "gdbm_block_store")
+                                             file
+                                             (logior O_RDWR O_CREAT)
+                                             #o644))
+            (s* (smart-block-store-open s #t))
+            (k  #vu8(1 2 3 4 5))
+            (v1 (u8-list->bytevector (iota 256)))
+            (v2 (u8-list->bytevector (iota 256 255 -1))))
+       (store-write-block s* k v1)                ; goes through
+       (store-write-block s* k v2)                ; doesn't go through
+       (let ((r (and (bytevector=? v1 (store-read-block s* k))
+                     (bytevector=? v1 (store-read-block s k)))))
+         (store-close s*)
+         r)))))
+
 (test-end)
 
 
