@@ -171,6 +171,10 @@ static chop_error_t integer_block_fetch (chop_block_fetcher_t *,
 					 chop_block_store_t *,
 					 chop_buffer_t *,
 					 size_t *);
+static chop_error_t integer_block_exists (chop_block_fetcher_t *,
+					  const chop_index_handle_t *,
+					  chop_block_store_t *,
+					  int *);
 
 static chop_error_t
 ibf_ctor (chop_object_t *object, const chop_class_t *class)
@@ -179,6 +183,7 @@ ibf_ctor (chop_object_t *object, const chop_class_t *class)
 
   fetcher = (chop_integer_block_fetcher_t *)object;
   fetcher->block_fetcher.fetch_block = integer_block_fetch;
+  fetcher->block_fetcher.block_exists = integer_block_exists;
   fetcher->block_fetcher.index_handle_class = &chop_integer_index_handle_class;
 
   return chop_log_init ("integer-block-fetcher", &fetcher->log);
@@ -191,6 +196,7 @@ ibf_dtor (chop_object_t *object)
 
   fetcher = (chop_integer_block_fetcher_t *)object;
   fetcher->block_fetcher.fetch_block = NULL;
+  fetcher->block_fetcher.block_exists = NULL;
   fetcher->block_fetcher.index_handle_class = NULL;
 
   chop_object_destroy ((chop_object_t *)&fetcher->log);
@@ -232,6 +238,28 @@ chop_integer_block_fetcher_log (chop_block_fetcher_t *fetcher)
   return (&hfetcher->log);
 }
 
+static chop_error_t
+integer_block_exists (chop_block_fetcher_t *block_fetcher,
+		      const chop_index_handle_t *index,
+		      chop_block_store_t *store,
+		      int *exists)
+{
+  chop_integer_index_handle_t *iih;
+  uint32_t id;
+  chop_block_key_t key;
+
+  if (!chop_object_is_a ((chop_object_t *) index,
+			 &chop_integer_index_handle_class))
+    return CHOP_INVALID_ARG;
+
+  iih = (chop_integer_index_handle_t *) index;
+  id = htonl (iih->id);
+
+  chop_block_key_init (&key, (char *) &id, sizeof (id), NULL, NULL);
+
+  return chop_store_block_exists (store, &key, exists);
+}
+
 static chop_error_t
 integer_block_fetch (chop_block_fetcher_t *block_fetcher,
 		     const chop_index_handle_t *index,
